@@ -4,24 +4,20 @@
 
     Lexer for FreeFem++ language.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-from pygments.lexer import RegexLexer, include, bygroups, inherit, words, \
-    default
-from pygments.token import Text, Comment, Operator, Keyword, Name, String, \
-    Number, Punctuation
+from pygments.token import Comment, Operator, Keyword, Name
 
-from pygments.lexers.c_cpp import CLexer, CppLexer
-from pygments.lexers import _mql_builtins
+from pygments.lexers.c_cpp import CppLexer
 
 __all__ = ['FreeFemLexer']
 
 
 class FreeFemLexer(CppLexer):
     """
-    For `FreeFem++ <https://freefem.org/>`_ source.
+    For FreeFem++ source.
 
     This is an extension of the CppLexer, as the FreeFem Language is a superset
     of C++.
@@ -30,6 +26,7 @@ class FreeFemLexer(CppLexer):
     """
 
     name = 'Freefem'
+    url = 'https://freefem.org/'
     aliases = ['freefem']
     filenames = ['*.edp']
     mimetypes = ['text/x-freefem']
@@ -875,8 +872,8 @@ class FreeFemLexer(CppLexer):
                 'using'
     }
 
-    def get_tokens_unprocessed(self, text):
-        for index, token, value in CppLexer.get_tokens_unprocessed(self, text):
+    def get_tokens_unprocessed(self, text, stack=('root',)):
+        for index, token, value in CppLexer.get_tokens_unprocessed(self, text, stack):
             if value in self.operators:
                 yield index, Operator, value
             elif value in self.types:
