@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 """
     pygments.style
     ~~~~~~~~~~~~~~
 
     Basic style object.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -135,7 +134,7 @@ class StyleMeta(type):
             color = _ansimap[color]
         bgcolor = t[4]
         if bgcolor in _deprecated_ansicolors:
-            bgcolor = _deprecated_ansicolors[color]
+            bgcolor = _deprecated_ansicolors[bgcolor]
         if bgcolor in ansicolors:
             bgansicolor = bgcolor
             bgcolor = _ansimap[bgcolor]
@@ -177,10 +176,10 @@ class Style(metaclass=StyleMeta):
     highlight_color = '#ffffcc'
 
     #: line number font color
-    line_number_color = '#000000'
+    line_number_color = 'inherit'
 
     #: line number background color
-    line_number_background_color = '#f0f0f0'
+    line_number_background_color = 'transparent'
 
     #: special line number font color
     line_number_special_color = '#000000'
@@ -190,3 +189,9 @@ class Style(metaclass=StyleMeta):
 
     #: Style definitions for individual token types.
     styles = {}
+
+    # Attribute for lexers defined within Pygments. If set
+    # to True, the style is not shown in the style gallery
+    # on the website. This is intended for language-specific
+    # styles.
+    web_style_gallery_exclude = False
